@@ -45,16 +45,16 @@ function(fnames, kind=1, Iendian=1, BIGLONG=FALSE, HEADONLY=FALSE , PLOT=-1, RAW
 
       fn = fnames[i]
       infile = fn
-    ####   print(fn);
+    ####   message(fn);
       ###  if this file does not exist, exit!
       if(file.exists(infile)==FALSE)
         {
-         print(paste(sep=' ', "file does not exist", fn) ); 
+         warning(paste(sep=' ', "file does not exist", fn) ); 
           next;
         }
       else
         {
-          ###  print(paste(sep=' ', "file exists", fn) );
+          ###  message(paste(sep=' ', "file exists", fn) );
 
         }
 ########
@@ -107,7 +107,7 @@ function(fnames, kind=1, Iendian=1, BIGLONG=FALSE, HEADONLY=FALSE , PLOT=-1, RAW
 
       if(kind==1)
         {
-        #####   print(paste("RAW=", RAW))
+        #####   message(paste("RAW=", RAW))
           
           DAT  = JSEGY.seis(fn, Iendian=Iendian, HEADONLY=HEADONLY , BIGLONG=BIGLONG, PLOT=PLOT, RAW=RAW)
           tmpGIVE[[i]] = DAT[[1]]
@@ -123,7 +123,7 @@ function(fnames, kind=1, Iendian=1, BIGLONG=FALSE, HEADONLY=FALSE , PLOT=-1, RAW
 
       if(kind==3)
         {
-          print("AH format currently not available")
+          warning("AH format currently not available")
           tmpGIVE[[i]] = NA
           next
         }
