@@ -18,6 +18,9 @@ function(DEVOL, log=0,  fl=0, fh=10 , col=col, ylog=FALSE, ygrid=FALSE, AXE=c(1,
    ## if(!exists(col))  {  col=rainbow(50) }
     if(length(col)<1) {  col=rainbow(50) }
 
+     oldpar <- par(no.readonly = TRUE)
+      on.exit(par(oldpar))
+
     
     perc = 0.85
     a = DEVOL$sig
@@ -41,7 +44,7 @@ function(DEVOL, log=0,  fl=0, fh=10 , col=col, ylog=FALSE, ygrid=FALSE, AXE=c(1,
     
     ##   image(x,why,log10(t(DSPEC[1:(numfreqs/2),])), add=TRUE, col = col,xlab='time', ylab='freq', axes=FALSE)
 
-   ##   print("in plotevol...")
+   ##   message("in plotevol...")
     
     if(identical(STYLE, "fft"))
        {
@@ -82,7 +85,7 @@ function(DEVOL, log=0,  fl=0, fh=10 , col=col, ylog=FALSE, ygrid=FALSE, AXE=c(1,
     
     trace = RPMG::RESCALE( a, perc , 1.0  , min(a, na.rm=TRUE), max(a, na.rm=TRUE) )
 
-  ##    print("in plotevol...2")
+  ##    message("in plotevol...2")
        
     lines(tim, trace)
 
@@ -97,7 +100,7 @@ function(DEVOL, log=0,  fl=0, fh=10 , col=col, ylog=FALSE, ygrid=FALSE, AXE=c(1,
     xtix = pretty(x, n=10)
     xtix = xtix[xtix>=min(x)&xtix<max(x)]
 
-    ### print(paste(sep=" ",min(x),  max(x), paste(xtix)))
+    ### message(paste(sep=" ",min(x),  max(x), paste(xtix)))
 
   #   xtix = c(floor(min(x)),xtix,  floor(max(x)))
     axis(3,tck=.01,at=xtix,labels=FALSE)
@@ -181,7 +184,7 @@ function(DEVOL, log=0,  fl=0, fh=10 , col=col, ylog=FALSE, ygrid=FALSE, AXE=c(1,
     else
       {
 
-        print("plotevol error in input amplitudes")
+        message("plotevol error in input amplitudes")
       }
     
 
